==> openshift-model-operatorhub-6.8.0-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/SubscriptionSpecFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SubscriptionSpecFluent<A extends SubscriptionSpecFluent<A>> extends BaseFluent<A>{
  public SubscriptionSpecFluent() {
  }
  public SubscriptionSpecFluent(SubscriptionSpec instance) {
    instance = (instance != null ? instance : new SubscriptionSpec());

    if (instance != null) {
      this.withChannel(instance.getChannel());
      this.withConfig(instance.getConfig());
      this.withInstallPlanApproval(instance.getInstallPlanApproval());
      this.withName(instance.getName());
      this.withSource(instance.getSource());
      this.withSourceNamespace(instance.getSourceNamespace());
      this.withStartingCSV(instance.getStartingCSV());
      this.withChannel(instance.getChannel());
      this.withConfig(instance.getConfig());
      this.withInstallPlanApproval(instance.getInstallPlanApproval());
      this.withName(instance.getName());
      this.withSource(instance.getSource());
      this.withSourceNamespace(instance.getSourceNamespace());
      this.withStartingCSV(instance.getStartingCSV());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String channel;
  private SubscriptionConfigBuilder config;
  private String installPlanApproval;
  private String name;
  private String source;
  private String sourceNamespace;
  private String startingCSV;
  private Map<String,Object> additionalProperties;
  public String getChannel() {
    return this.channel;
  }
  public A withChannel(String channel) {
    this.channel=channel; return (A) this;
  }
  public boolean hasChannel() {
    return this.channel != null;
  }
  public SubscriptionConfig buildConfig() {
    return this.config!=null ?this.config.build():null;
  }
  public A withConfig(SubscriptionConfig config) {
    _visitables.get("config").remove(this.config);
    if (config!=null){ this.config= new SubscriptionConfigBuilder(config); _visitables.get("config").add(this.config);} else { this.config = null; _visitables.get("config").remove(this.config); } return (A) this;
  }
  public boolean hasConfig() {
    return this.config != null;
  }
  public ConfigNested<A> withNewConfig() {
    return new ConfigNested(null);
  }
  public ConfigNested<A> withNewConfigLike(SubscriptionConfig item) {
    return new ConfigNested(item);
  }
  public ConfigNested<A> editConfig() {
    return withNewConfigLike(java.util.Optional.ofNullable(buildConfig()).orElse(null));
  }
  public ConfigNested<A> editOrNewConfig() {
    return withNewConfigLike(java.util.Optional.ofNullable(buildConfig()).orElse(new SubscriptionConfigBuilder().build()));
  }
  public ConfigNested<A> editOrNewConfigLike(SubscriptionConfig item) {
    return withNewConfigLike(java.util.Optional.ofNullable(buildConfig()).orElse(item));
  }
  public String getInstallPlanApproval() {
    return this.installPlanApproval;
  }
  public A withInstallPlanApproval(String installPlanApproval) {
    this.installPlanApproval=installPlanApproval; return (A) this;
  }
  public boolean hasInstallPlanApproval() {
    return this.installPlanApproval != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public boolean hasName() {
    return this.name != null;
  }
  public String getSource() {
    return this.source;
  }
  public A withSource(String source) {
    this.source=source; return (A) this;
  }
  public boolean hasSource() {
    return this.source != null;
  }
  public String getSourceNamespace() {
    return this.sourceNamespace;
  }
  public A withSourceNamespace(String sourceNamespace) {
    this.sourceNamespace=sourceNamespace; return (A) this;
  }
  public boolean hasSourceNamespace() {
    return this.sourceNamespace != null;
  }
  public String getStartingCSV() {
    return this.startingCSV;
  }
  public A withStartingCSV(String startingCSV) {
    this.startingCSV=startingCSV; return (A) this;
  }
  public boolean hasStartingCSV() {
    return this.startingCSV != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SubscriptionSpecFluent that = (SubscriptionSpecFluent) o;
    if (!java.util.Objects.equals(channel, that.channel)) return false;

    if (!java.util.Objects.equals(config, that.config)) return false;

    if (!java.util.Objects.equals(installPlanApproval, that.installPlanApproval)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(source, that.source)) return false;

    if (!java.util.Objects.equals(sourceNamespace, that.sourceNamespace)) return false;

    if (!java.util.Objects.equals(startingCSV, that.startingCSV)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(channel,  config,  installPlanApproval,  name,  source,  sourceNamespace,  startingCSV,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (channel != null) { sb.append("channel:"); sb.append(channel + ","); }
    if (config != null) { sb.append("config:"); sb.append(config + ","); }
    if (installPlanApproval != null) { sb.append("installPlanApproval:"); sb.append(installPlanApproval + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (source != null) { sb.append("source:"); sb.append(source + ","); }
    if (sourceNamespace != null) { sb.append("sourceNamespace:"); sb.append(sourceNamespace + ","); }
    if (startingCSV != null) { sb.append("startingCSV:"); sb.append(startingCSV + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class ConfigNested<N> extends SubscriptionConfigFluent<ConfigNested<N>> implements Nested<N>{
    ConfigNested(SubscriptionConfig item) {
      this.builder = new SubscriptionConfigBuilder(this, item);
    }
    SubscriptionConfigBuilder builder;
    public N and() {
      return (N) SubscriptionSpecFluent.this.withConfig(builder.build());
    }
    public N endConfig() {
      return and();
    }
    
  }
  
}

==> openshift-model-operatorhub-6.9.0-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/SubscriptionSpecFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class SubscriptionSpecFluent<A extends SubscriptionSpecFluent<A>> extends BaseFluent<A>{
  public SubscriptionSpecFluent() {
  }
  
  public SubscriptionSpecFluent(SubscriptionSpec instance) {
    this.copyInstance(instance);
  }
  private String channel;
  private SubscriptionConfigBuilder config;
  private String installPlanApproval;
  private String name;
  private String source;
  private String sourceNamespace;
  private String startingCSV;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(SubscriptionSpec instance) {
    instance = (instance != null ? instance : new SubscriptionSpec());
  
    if (instance != null) {
        this.withChannel(instance.getChannel());
        this.withConfig(instance.getConfig());
        this.withInstallPlanApproval(instance.getInstallPlanApproval());
        this.withName(instance.getName());
        this.withSource(instance.getSource());
        this.withSourceNamespace(instance.getSourceNamespace());
        this.withStartingCSV(instance.getStartingCSV());
        this.withChannel(instance.getChannel());
        this.withConfig(instance.getConfig());
        this.withInstallPlanApproval(instance.getInstallPlanApproval());
        this.withName(instance.getName());
        this.withSource(instance.getSource());
        this.withSourceNamespace(instance.getSourceNamespace());
        this.withStartingCSV(instance.getStartingCSV());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getChannel() {
    return this.channel;
  }
  
  public A withChannel(String channel) {
    this.channel=channel; return (A) this;
  }
  
  public boolean hasChannel() {
    return this.channel != null;
  }
  
  public SubscriptionConfig buildConfig() {
    return this.config!=null ?this.config.build():null;
  }
  
  public A withConfig(SubscriptionConfig config) {
    _visitables.get("config").remove(this.config);
    if (config!=null){ this.config= new SubscriptionConfigBuilder(config); _visitables.get("config").add(this.config);} else { this.config = null; _visitables.get("config").remove(this.config); } return (A) this;
  }
  
  public boolean hasConfig() {
    return this.config != null;
  }
  
  public ConfigNested<A> withNewConfig() {
    return new ConfigNested(null);
  }
  
  public ConfigNested<A> withNewConfigLike(SubscriptionConfig item) {
    return new ConfigNested(item);
  }
  
  public ConfigNested<A> editConfig() {
    return withNewConfigLike(java.util.Optional.ofNullable(buildConfig()).orElse(null));
  }
  
  public ConfigNested<A> editOrNewConfig() {
    return withNewConfigLike(java.util.Optional.ofNullable(buildConfig()).orElse(new SubscriptionConfigBuilder().build()));
  }
  
  public ConfigNested<A> editOrNewConfigLike(SubscriptionConfig item) {
    return withNewConfigLike(java.util.Optional.ofNullable(buildConfig()).orElse(item));
  }
  
  public String getInstallPlanApproval() {
    return this.installPlanApproval;
  }
  
  public A withInstallPlanApproval(String installPlanApproval) {
    this.installPlanApproval=installPlanApproval; return (A) this;
  }
  
  public boolean hasInstallPlanApproval() {
    return this.installPlanApproval != null;
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public String getSource() {
    return this.source;
  }
  
  public A withSource(String source) {
    this.source=source; return (A) this;
  }
  
  public boolean hasSource() {
    return this.source != null;
  }
  
  public String getSourceNamespace() {
    return this.sourceNamespace;
  }
  
  public A withSourceNamespace(String sourceNamespace) {
    this.sourceNamespace=sourceNamespace; return (A) this;
  }
  
  public boolean hasSourceNamespace() {
    return this.sourceNamespace != null;
  }
  
  public String getStartingCSV() {
    return this.startingCSV;
  }
  
  public A withStartingCSV(String startingCSV) {
    this.startingCSV=startingCSV; return (A) this;
  }
  
  public boolean hasStartingCSV() {
    return this.startingCSV != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SubscriptionSpecFluent that = (SubscriptionSpecFluent) o;
    if (!java.util.Objects.equals(channel, that.channel)) return false;
  
    if (!java.util.Objects.equals(config, that.config)) return false;
  
    if (!java.util.Objects.equals(installPlanApproval, that.installPlanApproval)) return false;
  
    if (!java.util.Objects.equals(name, that.name)) return false;
  
    if (!java.util.Objects.equals(source, that.source)) return false;
  
    if (!java.util.Objects.equals(sourceNamespace, that.sourceNamespace)) return false;
  
    if (!java.util.Objects.equals(startingCSV, that.startingCSV)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(channel,  config,  installPlanApproval,  name,  source,  sourceNamespace,  startingCSV,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (channel != null) { sb.append("channel:"); sb.append(channel + ","); }
    if (config != null) { sb.append("config:"); sb.append(config + ","); }
    if (installPlanApproval != null) { sb.append("installPlanApproval:"); sb.append(installPlanApproval + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (source != null) { sb.append("source:"); sb.append(source + ","); }
    if (sourceNamespace != null) { sb.append("sourceNamespace:"); sb.append(sourceNamespace + ","); }
    if (startingCSV != null) { sb.append("startingCSV:"); sb.append(startingCSV + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class ConfigNested<N> extends SubscriptionConfigFluent<ConfigNested<N>> implements Nested<N>{
    ConfigNested(SubscriptionConfig item) {
      this.builder = new SubscriptionConfigBuilder(this, item);
    }
    SubscriptionConfigBuilder builder;
    
    public N and() {
      return (N) SubscriptionSpecFluent.this.withConfig(builder.build());
    }
    
    public N endConfig() {
      return and();
    }
    
  
  }

}
